@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,6 +12,7 @@
 
 ImportImapSettingFinishPage::ImportImapSettingFinishPage(QWidget *parent)
     : QWidget(parent)
+    , mTextEdit(new QTextEdit(this))
 {
     auto mainlayout = new QVBoxLayout(this);
     mainlayout->setObjectName(QStringLiteral("mainlayout"));
@@ -20,16 +21,13 @@ ImportImapSettingFinishPage::ImportImapSettingFinishPage(QWidget *parent)
     label->setObjectName(QStringLiteral("label"));
     mainlayout->addWidget(label);
 
-    mTextEdit = new QTextEdit(this);
     mTextEdit->setObjectName(QStringLiteral("textedit"));
     mTextEdit->setAcceptRichText(true);
     mTextEdit->setReadOnly(true);
     mainlayout->addWidget(mTextEdit);
 }
 
-ImportImapSettingFinishPage::~ImportImapSettingFinishPage()
-{
-}
+ImportImapSettingFinishPage::~ImportImapSettingFinishPage() = default;
 
 void ImportImapSettingFinishPage::addSummary(const QString &name)
 {
